---
title: 바로오픈 서비스 안내
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 바로오픈 서비스 안내
  description: >-
    바로오픈 서비스란 PG 계약 시 ‘카드사 심사 절차’(약 2주 소요) 전에 우선적으로 빠른 결제 서비스 도입이 필요한 경우에 이용 가능한
    서비스입니다.
  keywords:
    - 바로오픈서비스
tags:
  - KG이니시스
  - NHN KCP
  - 토스페이먼츠
  - 결제대행사 계약
pgCompanies:
  - KG이니시스
  - 토스페이먼츠
  - NHN KCP
searchTags:
  - 토스페이먼츠
  - NHN KCP
  - KG이니시스
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="**바로오픈 서비스란?**
PG 계약 시 카드사 심사 절차(약 2주 소요) 전,
우선적으로 빠르게 결제 서비스 도입이 필요한 경우 이용 가능한 서비스입니다." />

### **지원 PG사**

**KG이니시스 / NHN KCP / 토스페이먼츠**

- 신청 즉시 이용 가능 : KG이니시스
- PG 입점 심사 완료 후 이용 가능 : NHN KCP , 토스페이먼츠
  - 참고 : 토스페이먼츠의 경우 “국내에서 7일 이내에 배송되는 실물 유형 제품” 한에서 바로오픈(미리오픈)서비스 이용이 가능하여, 희망하시는 경우 토스페이먼츠 고객센터를 통해 문의 부탁드립니다. \
    (토스페이먼츠에서 사이트 검토 후 가능 여부 안내드리고 있습니다.)

### **지원 결제수단**

- KG이니시스 : 카드(일시불만 지원) , 실시간 계좌이체, 가상계좌
- 토스페이먼츠 : 카드(일시불만 지원)
- NHN KCP : 카드(일시불만 지원)

### **수수료 및 정산**

바로오픈 서비스용의 별도 수수료가 발생되지 않으며 원래 결제대행사를 통한 결제 시 부과되는 일반 결제 수수료율만 발생됩니다.

**결제수수료율(부가세별도)**

- 카드 (일반사업자 기준) : 3.2%
- 실시간계좌이체 : 1.80%
- 가상계좌 : 건당 300원 (기본 수수료율과 동일 적용)
- 정산 주기 : 월 1회 (카드사 심사완료 후 변경 가능)
- 참고 : PG사 입점 가능한 업종에 한 해 이용이 가능하며 카드사 심사 시 반려된 경우 PG 서비스 이용이 중단될 수 있습니다. (PG사측로부터 입점 불가 업종으로 안내받으신 경우 결제 서비스는 중단됩니다)

<Callout content="1. 바로오픈 서비스는 정기결제 방식, 허브형 간편결제, 카드 할부 결제를 지원하지 않습니다. 
2. 추후 카드사 심사가 완료되면 신청 후 서비스 이용이 가능합니다.
3. 정기결제 서비스가 필요하신 경우 PG사 측과 빌링 특약/심사 절차가 필요합니다." icon="💡" title="참고사항" />
